utils::globalVariables(c("ts_lstm_create", "ts_lstm_fit", "ts_lstm_predict",
                         "ts_conv1d_create","ts_conv1d_fit", "ts_conv1d_predict",
                         "autoencoder_create", "autoencoder_fit", "autoencoder_encode", "autoencoder_encode_decode",
                         "vae_create", "vae_fit", "vae_encode", "vae_encode_decode", "aae_create",
                         "aae_fit", "adv_encode", "adv_encode_decode", "c2den_create", "c2den_encode_decode",
                         "c2den_fit", "cae2d_create", "cae_fit", "conv2d_encode_decode", "conv_encode", "conv_encode_decode",
                         "dns_ae_create", "dns_ae_fit", "dns_encode", "lae_fit", "lstm_encode", "lstm_encode_decode", "return_loss",
                         "var_encode", "var_encode_decode", "cae2d_fit", "cae_create", "dns_encode_decode",
                         "lae_create", "sae_create", "sae_fit", "dns_fit", "c2den_encode"))
